import 'package:flutter/material.dart';
import 'package:flutter/painting.dart';
import 'dart:math';

/// On Relative luminance: https://www.w3.org/TR/WCAG20/#relativeluminancedef
class RelativeLuminance {
  /// for a single color, we need to convert them to the sRGB spec. This means
  /// we need to blend the color either with white, or supplied background color.
  /// The background color can not contain alpha
  static double calculateFromColorWithBackground(Color color,
      {Color background = Colors.white}) {
    double relLum(double relSrgb) => (relSrgb <= 0.03928
        ? relSrgb / 12.92
        : pow(((relSrgb + 0.055) / 1.055), 2.4)) as double;

    ///    RsRGB = R8bit/255
    ///    GsRGB = G8bit/255
    ///    BsRGB = B8bit/255
    final _rSrgb = color.red / 255;
    final _gSrgb = color.green / 255;
    final _bSrgb = color.blue / 255;

    /// if RsRGB <= 0.03928 then R = RsRGB/12.92 else R = ((RsRGB+0.055)/1.055) ^ 2.4
    /// if GsRGB <= 0.03928 then G = GsRGB/12.92 else G = ((GsRGB+0.055)/1.055) ^ 2.4
    /// if BsRGB <= 0.03928 then B = BsRGB/12.92 else B = ((BsRGB+0.055)/1.055) ^ 2.4
    final rlRed = relLum(_rSrgb);
    final rlGreen = relLum(_gSrgb);
    final rlBlue = relLum(_bSrgb);

    /// L = 0.2126 * R + 0.7152 * G + 0.0722 * B ;
    return 0.2126 * rlRed + 0.7152 * rlGreen + 0.0722 * rlBlue;
  }
}
